An Experimental New Storage Format For Jupyter Notebooks
========================================================

Online documentation (and example of use):
    https://jupyter-format.readthedocs.io/

Source code repository (and issue tracker):
    https://github.com/mgeier/jupyter-format/

License:
    MIT -- see the file ``LICENSE`` for details.
